@@ -101,7 +101,7 @@ void TabSwitcherPluginView::setupActions()
     auto aNext = actionCollection()->addAction(QStringLiteral("view_lru_document_next"));
     aNext->setText(i18n("Last Used Views"));
     aNext->setIcon(QIcon::fromTheme(QStringLiteral("go-next-view-page")));
-    actionCollection()->setDefaultShortcut(aNext, Qt::CTRL | Qt::Key_Tab);
+    KActionCollection::setDefaultShortcut(aNext, Qt::CTRL | Qt::Key_Tab);
     aNext->setWhatsThis(i18n("Opens a list to walk through the list of last used views."));
     aNext->setStatusTip(i18n("Walk through the list of last used views"));
     connect(aNext, &QAction::triggered, this, &TabSwitcherPluginView::walkForward);
@@ -109,7 +109,7 @@ void TabSwitcherPluginView::setupActions()
     auto aPrev = actionCollection()->addAction(QStringLiteral("view_lru_document_prev"));
     aPrev->setText(i18n("Last Used Views (Reverse)"));
     aPrev->setIcon(QIcon::fromTheme(QStringLiteral("go-previous-view-page")));
-    actionCollection()->setDefaultShortcut(aPrev, Qt::CTRL | Qt::SHIFT | Qt::Key_Tab);
+    KActionCollection::setDefaultShortcut(aPrev, Qt::CTRL | Qt::SHIFT | Qt::Key_Tab);
     aPrev->setWhatsThis(i18n("Opens a list to walk through the list of last used views in reverse."));
     aPrev->setStatusTip(i18n("Walk through the list of last used views"));
     connect(aPrev, &QAction::triggered, this, &TabSwitcherPluginView::walkBackward);
@@ -117,7 +117,7 @@ void TabSwitcherPluginView::setupActions()
     auto aClose = actionCollection()->addAction(QStringLiteral("view_lru_document_close"));
     aClose->setText(i18n("Close View"));
     aClose->setShortcutContext(Qt::WidgetShortcut);
-    actionCollection()->setDefaultShortcut(aClose, Qt::CTRL | Qt::Key_W);
+    KActionCollection::setDefaultShortcut(aClose, Qt::CTRL | Qt::Key_W);
     aClose->setWhatsThis(i18n("Closes the selected view in the list of last used views."));
     aClose->setStatusTip(i18n("Closes the selected view in the list of last used views."));
     connect(aClose, &QAction::triggered, this, &TabSwitcherPluginView::closeView);
@@ -279,14 +279,14 @@ void TabSwitcherPluginView::updateViewGeometry()
     const int frameWidth = m_treeView->frameWidth();
     // const QSize viewSize(std::min(m_treeView->sizeHintForColumn(0) + 2 * frameWidth + m_treeView->verticalScrollBar()->width(), viewMaxSize.width()), // ORIG
     // line, sizeHintForColumn was QListView but is protected for QTreeView so we introduced sizeHintWidth()
-    const QSize viewSize(std::min(m_treeView->sizeHintWidth() + 2 * frameWidth + m_treeView->verticalScrollBar()->width(), viewMaxSize.width()),
-                         std::min(std::max(rowHeight * m_model->rowCount() + 2 * frameWidth, rowHeight * 6), viewMaxSize.height()));
+    const QSize viewSize(std::min(m_treeView->sizeHintWidth() + (2 * frameWidth) + m_treeView->verticalScrollBar()->width(), viewMaxSize.width()),
+                         std::min(std::max((rowHeight * m_model->rowCount()) + (2 * frameWidth), rowHeight * 6), viewMaxSize.height()));
 
     // Position should be central over the editor area, so map to global from
     // parent of central widget since the view is positioned in global coords
     const QPoint centralWidgetPos = window->parent() ? window->mapToGlobal(window->pos()) : window->pos();
-    const int xPos = std::max(0, centralWidgetPos.x() + (centralSize.width() - viewSize.width()) / 2);
-    const int yPos = std::max(0, centralWidgetPos.y() + (centralSize.height() - viewSize.height()) / 2);
+    const int xPos = std::max(0, centralWidgetPos.x() + ((centralSize.width() - viewSize.width()) / 2));
+    const int yPos = std::max(0, centralWidgetPos.y() + ((centralSize.height() - viewSize.height()) / 2));
 
     m_treeView->setFixedSize(viewSize);
     m_treeView->move(xPos, yPos);
